Learn R Programming

shinyTempSignal (version 0.0.8)

MCC_FluA_H3_tree: Example data: a tree of 76 H3 hemagglutinin gene sequences of a lineage containing swine and human influenza A viruses

Description

This example data was reported on Liang et al. 2014

Arguments

Value

a tree, phylo

Format

a tree with 76 sequences

Examples

Run this code
data(MCC_FluA_H3_tree)

Run the code above in your browser using DataLab